module.exports = defineTest({
	description: 'entry point facade creation',
	options: {
		input: ['main1.js', 'main2.js']
	}
});
